@@ -1,9 +1,9 @@
 #
-# $Id: Split.pm,v 0.39 2004/01/04 22:03:23 sts Exp $
+# $Id: Split.pm,v 0.40 2004/01/05 12:15:36 sts Exp $
 
 package Dir::Split;
 
-our $VERSION = '0.39';
+our $VERSION = '0.40';
 
 use 5.6.1;
 use strict;
@@ -18,12 +18,13 @@ our (# external data
         %failure,
         %track,
 
+        $Ret_status,
+
      # data
         @Files,
         %F_names_case,
         %F_names_char,
         $Path,
-        $Ret_Status,
         $Suffix,
 );
 
@@ -102,15 +103,14 @@ sub new {
       unless ref $Opt_ref eq 'HASH';
 
     my $class = ref ($pkg) || $pkg;
-    my $obj = Dir::Split::_tie_var($Opt_ref);
 
-    return bless $obj, $class;
+    return bless _tie_var($Opt_ref), $class;
 }
 
 #
 # _tie_var (\%hash)
 #
-# Assigns the interface options to the object.
+# ``Ties" class data.
 #
 
 sub _tie_var {
@@ -134,6 +134,7 @@ sub _tie_var {
                                   case        =>         'case',
                     },
     );
+
     my %assigned;
     foreach my $key (keys %$opt_ref) {
         if (ref $$opt_ref{$key} eq 'HASH') {
@@ -143,6 +144,7 @@ sub _tie_var {
         }
         else { $assigned{$assign{$key}} = $$opt_ref{$key} }
     }
+
     return \%assigned;
 };
 
@@ -196,21 +198,21 @@ sub split {
 
     # files found, split.
     if (@Files) {
-        $Ret_Status = ACTION;
-
-        #$o->_init_presets(); # unused atm.
+        $Ret_status = ACTION;
 
         # engine
         $o->_sort_files() if $o->{'mode'} eq 'num';
         $o->_suffix();
         $o->_move();
+
+        $Ret_status = FAILURE if %failure;
     }
     # no files? exit.
-    else { $Ret_Status = NO_ACTION }
+    else { $Ret_status = NO_ACTION }
 
-    $Ret_Status = FAILURE if %failure;
+    _clean_up();
 
-    return $Ret_Status;
+    return $Ret_status;
 }
 
 #
@@ -229,10 +231,10 @@ sub _sanity_input {
                      override    =>    'No override mode specified.',
                      ident       =>    'No subdir identifier specified.',
                      sep         =>    'No suffix separator specified.',
+                     length      =>    'No suffix length specified.',
                      f_limit     =>    'No file limit specified.',
                      f_sort      =>    'No file sort mode specified.',
                      num_contin  =>    'No continuation mode specified.',
-                     length      =>    'No suffix length specified.',
                      case        =>    'No suffix case mode specified.',
     );
 
@@ -259,6 +261,9 @@ sub _sanity_input {
         unless ($o->{'sep'}) {
             $err_input = $err_msg{'sep'}; last;
         }
+        unless ($o->{'length'} > 0) {
+            $err_input = $err_msg{'length'}; last;
+        }
         # numeric opts
         if ($o->{'mode'} eq 'num') {
             unless ($o->{'f_limit'} > 0) {
@@ -270,18 +275,12 @@ sub _sanity_input {
             unless ($o->{'num_contin'} =~ /^0|1$/) {
                 $err_input = $err_msg{'num_contin'}; last;
             }
-            unless ($o->{'length'} > 0) {
-                $err_input = $err_msg{'length'}; last;
-            }
         }
         # characteristic opts
         elsif ($o->{'mode'} eq 'char') {
             unless ($o->{'case'} eq 'lower' || $o->{'case'} eq 'upper') {
                 $err_input = $err_msg{'case'}; last;
             }
-            unless ($o->{'length'} > 0) {
-                $err_input = $err_msg{'length'}; last;
-            }
         }
     }
     croak $err_input if $err_input;
@@ -290,7 +289,7 @@ sub _sanity_input {
 #
 # _gather_files()
 #
-# Gathers the files from the source directory.
+# Gathers files.
 #
 
 sub _gather_files {
@@ -302,19 +301,10 @@ sub _gather_files {
     $track{'source'}{'files'} = scalar @Files;
 }
 
-#
-# _init_presets()
-#
-# Initializes var presets.
-#
-
-#sub _init_presets {
-#}
-
 #
 # _sort_files()
 #
-# Sorts the files.
+# Sorts files.
 #
 
 sub _sort_files {
@@ -395,8 +385,8 @@ sub _suffix_num_sum_up {
 #
 # _suffix_char()
 #
-# Evaluates filenames in source directory
-# and stores them in a hash associated with the leading
+# Evaluates filenames and stores them 
+# in a hash associated with the leading
 # characters of their filenames.
 #
 
@@ -436,7 +426,7 @@ sub _move {
 #
 # _move_num()
 #
-# Moves the files to numeric subdirs.
+# Moves files to numeric subdirs.
 #
 
 sub _move_num {
@@ -455,7 +445,7 @@ sub _move_num {
 #
 # _move_char()
 #
-# Moves the files to characteristic subdirs.
+# Moves files to characteristic subdirs.
 #
 
 sub _move_char {
@@ -473,7 +463,7 @@ sub _move_char {
 #
 # _dir_read (\$dir, \@files)
 #
-# Reads the files of a directory.
+# Reads files of a directory.
 #
 
 sub _dir_read {
@@ -498,7 +488,7 @@ sub _mkpath {
 
     return if -e $Path;
     mkpath $Path, $o->{'verbose'} or
-      croak "dir $Path could not be created: $!";
+      croak qq~dir $Path could not be created: $!~;
 
     $track{'target'}{'dirs'}++;
 }
@@ -506,7 +496,7 @@ sub _mkpath {
 #
 # _cp_unlink ($file)
 #
-# Copies files and unlinks them.
+# Copies and unlinks files.
 # Upon existing files / failures, debug data.
 #
 
@@ -542,14 +532,27 @@ sub _cp_unlink {
 sub _exists_and_not_override {
     my ($o, $path) = @_;
 
-    if (-e $path && $o->{'override'} != 1) {
-        $Ret_Status = EXISTS;
+    if (-e $path && !$o->{'override'}) {
+        $Ret_status = EXISTS;
         return 1;
     }
 
     return 0;
 }
 
+#
+# _clean_up()
+#
+# Undef non-class data.
+#
+
+sub _clean_up {
+    undef %F_names_case;
+    undef %F_names_char;
+    undef $Path;
+    undef $Suffix;
+}
+
 1;
 __END__
 
@@ -789,7 +792,7 @@ Above example: directory consisting 512 files successfully splitted to 128 direc
 =head3 existing
 
 If C<split()> returns a I<EXISTS>, this implys that the B<override> option is disabled and
-files could not be moved due to existing files within the target subdirectories; they will have
+files weren't moved due to existing files within the target subdirectories; they will have
 their paths appearing in C<@Dir::Split::exists>.
 
    file    @Dir::Split::exists    # existing files, not attempted to
@@ -807,7 +810,8 @@ will have their paths appearing in the according keys in C<%Dir::Split::failure>
            @{$Dir::Split::failure{'unlink'}}    # files that could be copied but not unlinked,
                                                 # rather seldom.
 
-It is highly recommended to evaluate those arrays on I<FAILURE>.
+It is recommended to evaluate those arrays on I<FAILURE>. A C<@Dir::Split::exists> array
+may coexist.
 
 =head1 EXAMPLES
 
@@ -849,26 +853,26 @@ B<characteristic splitting>
 
 =over 4
 
-=item Has the functionality of Dir::Split been tested?
+=item B<Has the functionality of C<Dir::Split> been tested?>
 
 Yes. I may not have covered all edging cases,
-but it should behave mostly I<sane>, if certain options
+but it should behave I<mostly> sane, if certain options
 such as numbering continuation are enabled and others,
 like overriding, are disabled.
 
-=item Portability?
+=item B<Portability?>
 
-Has not yet been extensively tested. Dir::Split relies mostly
-upon File:: nested modules in spite of filesystem
-operation such as copying, unlinking and selecting
-an appropriate path separator; thus it should
+Has not yet been extensively tested. C<Dir::Split>
+relies mostly upon File:: nested modules in spite of
+filesystem operations such as copying, unlinking and
+selecting an appropriate path separator; thus it should
 probably be portable.
 
-=item Will you add any additional features?
+=item B<Will you add any additional features?>
 
-Not unless they're a real benefit. Dir::Split is
-already heavyweight enough and I am rather careful
-in terms of new inclusions; proposals towards additions
+Not unless they prove to be of unique usefulness.
+C<Dir::Split> is already heavyweight enough and I am rather
+careful in terms of new inclusions; proposals towards additions
 should be well grounded.
 
 =back
